==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTasksFiltersTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTasksFiltersTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Reset reset;
	public _70_1_1610483189 _70_1_1610483189;
	public ComboFilterTemplate folder;
	public _71_1_0972382148 _71_1_0972382148;
	public ComboFilterTemplate nature;
	public _72_1_02050367528 _72_1_02050367528;
	public CheckFilterTemplate urgent;

    public AbstractTasksFiltersTemplate(B box) {
        super(box);
        id("tasksFiltersTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (reset == null) reset = register(new Reset(box()).<Reset>id("a999970518").owner(AbstractTasksFiltersTemplate.this));
		if (_70_1_1610483189 == null) _70_1_1610483189 = register(new _70_1_1610483189(box()).<_70_1_1610483189>id("a1407291573").owner(AbstractTasksFiltersTemplate.this));
		if (_70_1_1610483189 != null) folder = _70_1_1610483189.folder;
		if (_71_1_0972382148 == null) _71_1_0972382148 = register(new _71_1_0972382148(box()).<_71_1_0972382148>id("a_710841223").owner(AbstractTasksFiltersTemplate.this));
		if (_71_1_0972382148 != null) nature = _71_1_0972382148.nature;
		if (_72_1_02050367528 == null) _72_1_02050367528 = register(new _72_1_02050367528(box()).<_72_1_02050367528>id("a220864836").owner(AbstractTasksFiltersTemplate.this));
		if (_72_1_02050367528 != null) urgent = _72_1_02050367528.urgent;
	}

	public class Reset extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

		public Reset(B box) {
			super(box);
			_title("Resetear filtros");
			_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _70_1_1610483189 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate folder;

		public _70_1_1610483189(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (folder == null) folder = register(new ComboFilterTemplate((UnitBox)box()).id("a_1119767663"));
		}
	}

	public class _71_1_0972382148 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate nature;

		public _71_1_0972382148(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nature == null) nature = register(new ComboFilterTemplate((UnitBox)box()).id("a_1099922199"));
		}
	}

	public class _72_1_02050367528 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public CheckFilterTemplate urgent;

		public _72_1_02050367528(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (urgent == null) urgent = register(new CheckFilterTemplate((UnitBox)box()).id("a_1080734558"));
		}
	}
}

==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTasksFiltersTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTasksFiltersTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Reset reset;
	public _70_1_1610483189 _70_1_1610483189;
	public ComboFilterTemplate folder;
	public _71_1_0972382148 _71_1_0972382148;
	public ComboFilterTemplate nature;
	public _72_1_1682861417 _72_1_1682861417;
	public ComboFilterTemplate type;
	public _73_1_02050367528 _73_1_02050367528;
	public CheckFilterTemplate urgent;

    public AbstractTasksFiltersTemplate(B box) {
        super(box);
        id("tasksFiltersTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (reset == null) reset = register(new Reset(box()).<Reset>id("a999970518").owner(AbstractTasksFiltersTemplate.this));
		if (_70_1_1610483189 == null) _70_1_1610483189 = register(new _70_1_1610483189(box()).<_70_1_1610483189>id("a1407291573").owner(AbstractTasksFiltersTemplate.this));
		if (_70_1_1610483189 != null) folder = _70_1_1610483189.folder;
		if (_71_1_0972382148 == null) _71_1_0972382148 = register(new _71_1_0972382148(box()).<_71_1_0972382148>id("a_710841223").owner(AbstractTasksFiltersTemplate.this));
		if (_71_1_0972382148 != null) nature = _71_1_0972382148.nature;
		if (_72_1_1682861417 == null) _72_1_1682861417 = register(new _72_1_1682861417(box()).<_72_1_1682861417>id("a1598564786").owner(AbstractTasksFiltersTemplate.this));
		if (_72_1_1682861417 != null) type = _72_1_1682861417.type;
		if (_73_1_02050367528 == null) _73_1_02050367528 = register(new _73_1_02050367528(box()).<_73_1_02050367528>id("a1728416645").owner(AbstractTasksFiltersTemplate.this));
		if (_73_1_02050367528 != null) urgent = _73_1_02050367528.urgent;
	}

	public class Reset extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

		public Reset(B box) {
			super(box);
			_title("Resetear filtros");
			_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _70_1_1610483189 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate folder;

		public _70_1_1610483189(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (folder == null) folder = register(new ComboFilterTemplate((UnitBox)box()).id("a_1119767663"));
		}
	}

	public class _71_1_0972382148 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate nature;

		public _71_1_0972382148(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nature == null) nature = register(new ComboFilterTemplate((UnitBox)box()).id("a_1099922199"));
		}
	}

	public class _72_1_1682861417 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate type;

		public _72_1_1682861417(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = register(new ComboFilterTemplate((UnitBox)box()).id("a374271195"));
		}
	}

	public class _73_1_02050367528 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public CheckFilterTemplate urgent;

		public _73_1_02050367528(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (urgent == null) urgent = register(new CheckFilterTemplate((UnitBox)box()).id("a_1277248063"));
		}
	}
}
